Clazz.declarePackage("JM");
Clazz.load(["JM.ProteinStructure"], "JM.Annotation", null, function(){
var c$ = Clazz.declareType(JM, "Annotation", JM.ProteinStructure);
});
;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
